@@ -177,6 +177,10 @@ class CloudFlow:
         except aiohttp.ClientResponseError as e:
             if e.status == HTTPStatus.UNAUTHORIZED:
                 _exit_error('Please login first.')
+            elif e.status == HTTPStatus.NOT_FOUND:
+                logger.info(
+                    'You don\'t have any Flows deployed. Please use `jc deploy`'
+                )
 
     async def _upload_project(self, filepaths: List[Path], tags: Dict = {}) -> str:
         data = aiohttp.FormData()
@@ -259,7 +263,7 @@ class CloudFlow:
     async def logstream(params):
         logger.debug(f'Asked to stream logs with params {params}')
 
-        log_msg = logger.debug if 'request_id' in params else logger.info
+        log_msg = logger.debug if 'request_id' in params else print
 
         try:
             async with aiohttp.ClientSession() as session:
@@ -307,7 +311,12 @@ class CloudFlow:
             pbar.console.print(self)
             pbar.update(pb_task, description='Finishing', advance=1)
             self._c_logstream_task.cancel()
-            return self
+
+        # ask feedback
+        from .auth import Survey
+
+        Survey().count().ask(threshold=3)
+        return self
 
     async def __aexit__(self, *args, **kwargs):
         with pbar:
